CredentialStatus class
The resolved status of one credential.
Constructors
- CredentialStatus(int value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
Whether the credential is still valid (status 0).
no setter
- kind → CredentialStatusKind
-
The well-known meaning of value.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The raw status value read from the list (0 = valid, 1 = invalid/revoked,
2 = suspended, 3+ = application specific).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited